@@ -83,7 +83,10 @@ unsigned int hfst_ol_to_hfst_basic_add_state
       bool weighted = t->get_header().probe_flag(hfst_ol::Weighted);
       const hfst_ol::SymbolTable& symbols
         = t->get_alphabet().get_symbol_table();
-      
+      for (hfst_ol::SymbolTable::const_iterator it = symbols.begin();
+           it != symbols.end(); ++it) {
+          basic->add_symbol_to_alphabet(*it);
+      }
       
       /* This contains indices to either (1) the start of a set of entries
          in the transition index table, or (2) the boundary before a set
@@ -203,6 +206,16 @@ void get_states_and_symbols(
         ++state_number;
     }
 
+    // We finally add symbols from the source alphabet that don't appear in any
+    // transitions to "other symbols".
+    StringSet source_alphabet = t->get_alphabet();
+    for (StringSet::iterator it = source_alphabet.begin();
+         it != source_alphabet.end(); ++it) {
+        if (input_symbols->count(*it) == 0 && flag_diacritics->count(*it) == 0) {
+            other_symbols->insert(*it);
+        }
+    }
+
     std::map<std::string, SymbolNumber> string_symbol_map;
 
     // Collect symbols if we need to
@@ -295,7 +308,9 @@ void get_states_and_symbols(
   {
       const float packing_aggression = (float)0.85; // double -> const float
       const int floor_jump_threshold = 4; // a packing aggression parameter
-      //bool quick = options == "quick";
+
+      bool empty_alphabet = (options.find("empty_alphabet") != std::string::npos);
+      
       // The transition array is indexed starting from this constant
       const unsigned int TA_OFFSET = 2147483648u;
 
@@ -441,6 +456,11 @@ void get_states_and_symbols(
         state_placeholders,
         flag_symbols);
 
+    if (empty_alphabet) {
+        symbol_table.clear();
+        seen_input_symbols = 0;
+    }
+    
     hfst_ol::TransducerAlphabet alphabet(symbol_table);
     hfst_ol::TransducerHeader header(seen_input_symbols,
                                      hfst::size_t_to_ushort(symbol_table.size()),
@@ -516,6 +536,10 @@ int main(int argc, char * argv[])
     hfst::HfstTransducer cmp_w(basic_w, hfst::TROPICAL_OPENFST_TYPE);
     assert(cmp.compare(hfst::HfstTransducer(*basic_converted, hfst::TROPICAL_OPENFST_TYPE)));
     assert(cmp_w.compare(hfst::HfstTransducer(*basic_converted_w, hfst::TROPICAL_OPENFST_TYPE)));
+    delete basic_ol;
+    delete basic_olw;
+    delete basic_converted;
+    delete basic_converted_w;
     
     std::cout << "ok" << std::endl;
     return 0;
