@@ -1,10 +1,10 @@
-// Copyright (c) 2016 University of Helsinki                          
-//                                                                    
-// This library is free software; you can redistribute it and/or      
-// modify it under the terms of the GNU Lesser General Public         
-// License as published by the Free Software Foundation; either       
+// Copyright (c) 2016 University of Helsinki
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
 // version 3 of the License, or (at your option) any later version.
-// See the file COPYING included with this distribution for more      
+// See the file COPYING included with this distribution for more
 // information.
 
 #ifndef _SFST_TRANSDUCER_H_
@@ -14,29 +14,26 @@
 #include "HfstFlagDiacritics.h"
 #include "HfstSymbolDefs.h"
 #include "HfstExtractStrings.h"
-#include "back-ends/sfst/interface.h"
-#include "back-ends/sfst/fst.h"
+
+namespace SFST { class Transducer; typedef short unsigned int Character; class Alphabet; class Label; }
+
 #include <cstdio>
 #include <string>
 #include <sstream>
-#include <iostream>
+#include <iosfwd>
 
 /** @file SfstTransducer.h
     \brief Declarations of functions and datatypes that form a bridge between
     HFST API and SFST. */
 
-namespace hfst { 
+namespace hfst {
 namespace implementations
 {
-  //using namespace SFST;
   typedef SFST::Transducer Transducer;
-  ;
   using std::ostream;
   using std::ostringstream;
 
-  void sfst_set_hopcroft(bool);
-
-  class SfstInputStream 
+  class SfstInputStream
   {
   private:
     std::string filename;
@@ -69,51 +66,27 @@ namespace implementations
     static bool is_fst(std::istream &s);
   };
 
-  class SfstOutputStream 
+  class SfstOutputStream
   {
   private:
     std::string filename;
     FILE *ofile;
-    //void write_3_0_library_header(FILE *file, bool is_minimal);
   public:
-    SfstOutputStream(void); 
+    SfstOutputStream(void);
     SfstOutputStream(const std::string &filename);
     void close(void);
     void write(const char &c);
     void append_implementation_specific_header_data
       (std::vector<char> &header, SFST::Transducer *t);
     void write_transducer(SFST::Transducer * transducer);
-  };
+  };  
+
+  void sfst_set_hopcroft(bool);
+
 
-  class HfstNode2Int {
-    
-    struct hashf {
-      size_t operator()(const SFST::Node *node) const {
-    return (size_t)node;
-      }
-    };
-    struct equalf {
-      int operator()(const SFST::Node *n1, const SFST::Node *n2) const {
-    return (n1 == n2);
-      }
-    };
-    typedef SFST::hash_map<SFST::Node*, int, hashf, equalf> NL;
-    
-  private:
-    NL number;
-    
-  public:
-    int &operator[]( SFST::Node *node ) {
-      NL::iterator it=number.find(node);
-      if (it == number.end())
-    return number.insert(NL::value_type(node, 0)).first->second;
-      return it->second;
-    };
-  };
-  
-  
   class SfstTransducer
     {
+#if HAVE_SFST
     public:
       static SFST::Transducer * create_empty_transducer(void);
       static SFST::Transducer * create_epsilon_transducer(void);
@@ -182,12 +155,6 @@ namespace implementations
       static void print_test(SFST::Transducer *t);
       static void print_alphabet(SFST::Transducer *t);
 
-      static unsigned int get_biggest_symbol_number(SFST::Transducer * t);
-
-      static StringVector get_symbol_vector(SFST::Transducer * t);
-
-      static std::map<std::string, unsigned int> get_symbol_map(SFST::Transducer * t);
-
       static SFST::Transducer * disjunct(SFST::Transducer * t, const StringPairVector &spv);
 
       static StringPairSet get_symbol_pairs(SFST::Transducer *t);
@@ -196,24 +163,33 @@ namespace implementations
       static unsigned int number_of_states(SFST::Transducer *t);
       static unsigned int number_of_arcs(SFST::Transducer *t);
 
-      static StringSet get_alphabet(SFST::Transducer *t);
+
       static void insert_to_alphabet(SFST::Transducer *t, const std::string &symbol);
       static void remove_from_alphabet
     (SFST::Transducer *t, const std::string &symbol);
-      static unsigned int get_symbol_number(SFST::Transducer *t, 
-                        const std::string &symbol);
 
     protected:
       static void initialize_alphabet(SFST::Transducer *t);
       static SFST::Transducer * expand_arcs(SFST::Transducer * t, StringSet &unknown);
 
-      static void expand_node( SFST::Transducer *t, SFST::Node *origin, SFST::Label &l, 
+      static void expand_node( SFST::Transducer *t, SFST::Node *origin, SFST::Label &l,
                                SFST::Node *target, hfst::StringSet &s );
       static void expand2
         ( SFST::Transducer *t, SFST::Node *node,
           hfst::StringSet &new_symbols, std::set<SFST::Node*> &visited_nodes );
       static void expand(SFST::Transducer *t, hfst::StringSet &new_symbols);
 
+#endif
+      // needed in transducer format conversions
+    public:
+      static void delete_transducer(SFST::Transducer * t);
+      static unsigned int get_symbol_number(SFST::Transducer *t,
+					    const std::string &symbol);
+      static StringSet get_alphabet(SFST::Transducer *t);
+      static unsigned int get_biggest_symbol_number(SFST::Transducer * t);
+      static StringVector get_symbol_vector(SFST::Transducer * t);
+      static std::map<std::string, unsigned int> get_symbol_map(SFST::Transducer * t);      
     };
+
 } }
 #endif
