@@ -36,6 +36,9 @@
 #include "../../HfstSymbolDefs.h"
 #include "../../HfstDataTypes.h"
 
+#include <unicode/unistr.h>
+#include <unicode/uchar.h>
+
 #ifdef _MSC_VER
  #include <BaseTsd.h>
  typedef SSIZE_T ssize_t;
@@ -378,7 +381,10 @@ protected:
     SymbolNumber default_symbol;
     SymbolNumber identity_symbol;
     SymbolNumber orig_symbol_count;
-  
+
+    enum UnicodeClassCacheValue { upperalpha, loweralpha, whitespace, no_value, other };
+    std::vector<UnicodeClassCacheValue> unicode_cache;
+
 public:
     TransducerAlphabet()
         {
@@ -392,6 +398,10 @@ public:
                        SymbolNumber symbol_count,
                        bool preserve_diacritic_strings = true);
     TransducerAlphabet(const SymbolTable& st);
+    virtual ~TransducerAlphabet() {}
+
+    static void fake_read_alphabet(std::istream& is,
+                                   SymbolNumber symbol_count);
   
     void display() const;
   
@@ -410,6 +420,14 @@ public:
     bool is_flag_diacritic(SymbolNumber symbol) const
         { return fd_table.is_diacritic(symbol); }
     bool is_like_epsilon(SymbolNumber symbol) const;
+    virtual bool is_meta_arc(SymbolNumber symbol) const;
+
+    void cache_unicode_class(SymbolNumber symbol);
+
+    bool is_unicode_alpha(SymbolNumber symbol);
+    bool is_unicode_upperalpha(SymbolNumber symbol);
+    bool is_unicode_loweralpha(SymbolNumber symbol);
+    bool is_unicode_whitespace(SymbolNumber symbol);
     
     const SymbolTable& get_symbol_table() const
         { return symbol_table; }
@@ -834,6 +852,30 @@ struct DoubleTape: public std::vector<SymbolPair>
             this->operator[](pos) = SymbolPair(in, out);
         }
 
+    void write(unsigned int pos, std::vector<SymbolNumber> & vec)
+        {
+            while (pos + vec.size() >= this->size()) {
+                this->push_back(SymbolPair());
+            }
+            for (size_t i = 0; i < vec.size(); ++i) {
+                this->operator[](pos + i) = SymbolPair(vec[i], vec[i]);
+            }
+        }
+
+    void write(unsigned int pos, std::pair<SymbolNumberVector::iterator,
+               SymbolNumberVector::iterator> start_and_end)
+        {
+            size_t size = start_and_end.second - start_and_end.first;
+            while (pos + size >= this->size()) {
+                this->push_back(SymbolPair());
+            }
+            for (size_t i = 0; i < size; ++i) {
+                this->operator[](pos + i) =
+                    SymbolPair(*(start_and_end.first + i),
+                               *(start_and_end.first + i));
+            }
+        }
+
     DoubleTape extract_slice(unsigned int start, unsigned int stop)
         {
             DoubleTape retval;
