@@ -173,6 +173,7 @@ XreCompiler::define(const std::string& name, const std::string& xre)
         }
       return false;
     }
+  this->undefine(name);
   definitions_[name] = compiled;
   return true;
 }
@@ -186,6 +187,7 @@ XreCompiler::define_list(const std::string& name, const std::set<std::string>& s
 void
 XreCompiler::define(const std::string& name, const HfstTransducer & transducer)
 {
+  this->undefine(name);
   definitions_[name] = new HfstTransducer(transducer);
 }
 
@@ -219,10 +221,11 @@ XreCompiler::is_function_definition(const std::string & name)
 void
 XreCompiler::undefine(const std::string& name)
 {
-if (definitions_.find(name) != definitions_.end())
+  auto const it = definitions_.find(name);
+  if (it != definitions_.end())
   {
-    delete definitions[name];
-    definitions_.erase(name);
+    delete it->second;
+    definitions_.erase(it);
   }
 }
 
