@@ -1,9 +1,11 @@
 import hfst
-from sys import argv
-if len(argv) != 2:
+import hfst_commandline
+options = hfst_commandline.hfst_getopt('',[],1)
+
+if len(options[1]) == 0:
     raise RuntimeError('Usage: hfst-invert.py INFILE')
 
-istr = hfst.HfstInputStream(argv[1])
+istr = hfst.HfstInputStream(options[1][0])
 ostr = hfst.HfstOutputStream(type=istr.get_type())
 
 while(not istr.is_eof()):
@@ -11,6 +13,6 @@ while(not istr.is_eof()):
     tr.invert()
     tr.write(ostr)
     ostr.flush()
-      
+
 istr.close()
 ostr.close()
