@@ -1,19 +1,16 @@
 import hfst
-from sys import argv
-if len(argv) != 4:
-    raise RuntimeError('Usage: hfst-project.py INFILE -p [input|output]')
+import hfst_commandline
 
-ifile=None
 level=None
-for arg in argv[1:]:
-    if arg == '-p' or arg == '--project':
-        level='next'
-    elif level == 'next':
-        level = arg
-    else:
-        ifile = arg
+short_getopts='p:'
+long_getopts=['project=']
+options = hfst_commandline.hfst_getopt(short_getopts, long_getopts, 1)
+
+for opt in options[0]:
+    if opt[0] == '-p' or opt[0] == '--project':
+        level = opt[1]
         
-istr = hfst.HfstInputStream(ifile)
+istr = hfst_commandline.get_one_hfst_input_stream(options)[0]
 ostr = hfst.HfstOutputStream(type=istr.get_type())
 
 while(not istr.is_eof()):
