@@ -1,6 +1,8 @@
 import hfst
+import hfst_commandline
 
-istr = hfst.HfstInputStream()
+options = hfst_commandline.hfst_getopt('', [], 0)
+istr = hfst_commandline.get_one_hfst_input_stream(options)[0]
 n=1
 for tr in istr:
     ostr = hfst.HfstOutputStream(filename=str(n) + ".hfst", type=tr.get_type())
