@@ -26,6 +26,7 @@
 #endif
 
 #include <fstream>
+#include <memory>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
@@ -297,21 +298,21 @@ int main( int argc, char **argv ) {
     verbose_printf("Reading from %s, writing to %s\n",
         inputfilename, outfilename);
     // here starts the buffer handling part
-    HfstInputStream* instream = NULL;
+    std::unique_ptr<HfstInputStream> instream;
     try {
-        instream = (inputfile != stdin) ?
-        new HfstInputStream(inputfilename) : new HfstInputStream();
+        instream.reset((inputfile != stdin) ?
+        new HfstInputStream(inputfilename) : new HfstInputStream());
     } // NotTransducerStreamException
     catch (const HfstException e) {
         error(EXIT_FAILURE, 0, "%s is not a valid transducer file",
               inputfilename);
         return EXIT_FAILURE;
     }
-    HfstOutputStream* outstream = (outfile != stdout) ?
-                new HfstOutputStream(outfilename, instream->get_type()) :
-                new HfstOutputStream(instream->get_type());
+    auto outstream = (outfile != stdout) ?
+        std::make_unique<HfstOutputStream>(outfilename, instream->get_type()) :
+        std::make_unique<HfstOutputStream>(instream->get_type());
 
-    if ( is_input_stream_in_ol_format(instream, "hfst-affix-guessify"))
+    if ( is_input_stream_in_ol_format(*instream, "hfst-affix-guessify"))
       {
         return EXIT_FAILURE;
       }
