@@ -14,5 +14,5 @@ extern char * optarg;
 extern int optopt;
 extern int optind;
 
-char getopt_long(int argc, char * /*const*/ argv [], const char * optstring, 
+int getopt_long(int argc, char * /*const*/ argv [], const char * optstring,
                  const struct option * longopts, int * longindex);
