@@ -29,6 +29,7 @@
 #include <fstream>
 #include <set>
 #include <map>
+#include <memory>
 #include <sstream>
 
 using std::set;
@@ -244,11 +245,11 @@ int main( int argc, char **argv )
            inputfilename, outfilename);
     
     // here starts the buffer handling part
-    HfstInputStream * instream = NULL;
+    std::unique_ptr<HfstInputStream> instream;
 
     try
       {
-    instream = (inputfile != stdin ?
+        instream.reset(inputfile != stdin ?
             new HfstInputStream(inputfilename) :
             new HfstInputStream());
       }
@@ -376,8 +377,6 @@ int main( int argc, char **argv )
     (*out) << std::endl;
       }
 
-    delete instream;
-
     if (outfile != stdout)
       { assert(out != &std::cout); delete out; }
 
