@@ -4,7 +4,6 @@
 //!
 //! @author HFST Team
 
-
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation, version 3 of the License.
@@ -18,15 +17,15 @@
 //  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #ifdef WINDOWS
 #include <io.h>
 #endif
 
-#include <iostream>
 #include <fstream>
+#include <iostream>
 #include <memory>
 
 #include <cstdio>
@@ -35,25 +34,24 @@
 #include <getopt.h>
 
 #ifdef PROFILE
- #include <time.h>
+#include <time.h>
 #endif
 
+#include "HfstInputStream.h"
+#include "HfstOutputStream.h"
+#include "HfstTransducer.h"
 #include "hfst-commandline.h"
 #include "hfst-program-options.h"
 #include "hfst-tool-metadata.h"
-#include "HfstTransducer.h"
-#include "HfstInputStream.h"
-#include "HfstOutputStream.h"
 
 #include "inc/globals-common.h"
 #include "inc/globals-unary.h"
 
-using hfst::HfstTransducer;
 using hfst::HfstInputStream;
 using hfst::HfstOutputStream;
+using hfst::HfstTransducer;
 
-
-static bool encode_weights=false;
+static bool encode_weights = false;
 
 // add tools-specific variables here
 
@@ -62,14 +60,17 @@ print_usage()
 {
     // c.f. http://www.gnu.org/prep/standards/standards.html#g_t_002d_002dhelp
     // Usage line
-    fprintf(message_out, "Usage: %s [OPTIONS...] [INFILE]\n"
-           "Minimize a transducer\n"
-        "\n", program_name);
+    fprintf(message_out,
+            "Usage: %s [OPTIONS...] [INFILE]\n"
+            "Minimize a transducer\n"
+            "\n",
+            program_name);
 
     print_common_program_options(message_out);
     print_common_unary_program_options(message_out);
     fprintf(message_out, "Command-specific options:\n");
-    fprintf(message_out, "  -E, --encode-weights         Encode weights when minimizing\n"
+    fprintf(message_out,
+            "  -E, --encode-weights         Encode weights when minimizing\n"
             "                               (default is false).\n\n");
     print_common_unary_program_parameter_instructions(message_out);
     fprintf(message_out, "\n");
@@ -78,27 +79,24 @@ print_usage()
     print_more_info();
 }
 
-
 int
-parse_options(int argc, char** argv)
+parse_options(int argc, char **argv)
 {
     extend_options_getenv(&argc, &argv);
     // use of this function requires options are settable on global scope
     while (true)
     {
-        static const struct option long_options[] =
-        {
-          HFST_GETOPT_COMMON_LONG,
-          HFST_GETOPT_UNARY_LONG,
-          // add tool-specific options here
-          {"encode-weights", no_argument, 0, 'E'},
-          {0,0,0,0}
-        };
+        static const struct option long_options[]
+            = { HFST_GETOPT_COMMON_LONG,
+                HFST_GETOPT_UNARY_LONG,
+                // add tool-specific options here
+                { "encode-weights", no_argument, 0, 'E' },
+                { 0, 0, 0, 0 } };
         int option_index = 0;
         // add tool-specific options here
-        int c = getopt_long(argc, argv, HFST_GETOPT_COMMON_SHORT
-                             HFST_GETOPT_UNARY_SHORT "E",
-                             long_options, &option_index);
+        int c = getopt_long(
+            argc, argv, HFST_GETOPT_COMMON_SHORT HFST_GETOPT_UNARY_SHORT "E",
+            long_options, &option_index);
         if (-1 == c)
         {
             break;
@@ -107,12 +105,11 @@ parse_options(int argc, char** argv)
         switch (c)
         {
 #include "inc/getopt-cases-common.h"
-#include "inc/getopt-cases-unary.h"
 #include "inc/getopt-cases-error.h"
+#include "inc/getopt-cases-unary.h"
         case 'E':
-          encode_weights=true;
-          break;
-
+            encode_weights = true;
+            break;
         }
     }
 
@@ -122,24 +119,25 @@ parse_options(int argc, char** argv)
 }
 
 int
-process_stream(HfstInputStream& instream, HfstOutputStream& outstream)
+process_stream(HfstInputStream &instream, HfstOutputStream &outstream)
 {
-  //instream.open();
-  //outstream.open();
-    
-    size_t transducer_n=0;
-    while(instream.is_good())
+    // instream.open();
+    // outstream.open();
+
+    size_t transducer_n = 0;
+    while (instream.is_good())
     {
         transducer_n++;
         HfstTransducer trans(instream);
-        char* inputname = hfst_get_name(trans, inputfilename);
-        if (transducer_n==1)
+        char *inputname = hfst_get_name(trans, inputfilename);
+        if (transducer_n == 1)
         {
-          verbose_printf("Minimizing %s...\n", inputname);
+            verbose_printf("Minimizing %s...\n", inputname);
         }
         else
         {
-          verbose_printf("Minimizing %s..." SIZE_T_SPECIFIER "\n", inputname, transducer_n);
+            verbose_printf("Minimizing %s..." SIZE_T_SPECIFIER "\n", inputname,
+                           transducer_n);
         }
 
 #ifdef PROFILE
@@ -152,7 +150,8 @@ process_stream(HfstInputStream& instream, HfstOutputStream& outstream)
 #ifdef PROFILE
         t = clock() - t;
         hfst::set_minimize_even_if_already_minimal(val);
-        std::cerr << "Minimization took " << ((float)t)/CLOCKS_PER_SEC << " seconds" << std::endl;
+        std::cerr << "Minimization took " << ((float)t) / CLOCKS_PER_SEC
+                  << " seconds" << std::endl;
 #endif
 
         hfst_set_name(trans, trans, "minimize");
@@ -166,11 +165,12 @@ process_stream(HfstInputStream& instream, HfstOutputStream& outstream)
     return EXIT_SUCCESS;
 }
 
-
-int main( int argc, char **argv ) {
+int
+main(int argc, char **argv)
+{
 #ifdef WINDOWS
-  _setmode(0, _O_BINARY);
-  _setmode(1, _O_BINARY);
+    _setmode(0, _O_BINARY);
+    _setmode(1, _O_BINARY);
 #endif
 
     hfst_set_program_name(argv[0], "0.1", "HfstMinimize");
@@ -189,49 +189,54 @@ int main( int argc, char **argv ) {
         fclose(outfile);
     }
 
-
     bool enc = hfst::get_encode_weights();
     if (encode_weights)
-      {
+    {
         hfst::set_encode_weights(true);
-      }
+    }
 
-    verbose_printf("Reading from %s, writing to %s\n",
-        inputfilename, outfilename);
+    verbose_printf("Reading from %s, writing to %s\n", inputfilename,
+                   outfilename);
     // here starts the buffer handling part
     std::unique_ptr<HfstInputStream> instream;
-    try {
-      instream.reset((inputfile != stdin) ?
-        new HfstInputStream(inputfilename) : new HfstInputStream());
+    try
+    {
+        instream.reset((inputfile != stdin)
+                           ? new HfstInputStream(inputfilename)
+                           : new HfstInputStream());
     }
-    catch(const ImplementationTypeNotAvailableException & e) {
-      error(EXIT_FAILURE, 0, "file %s is in %s format which is not available",
-            inputfilename, hfst::implementation_type_to_format(instream->get_type()));
-      return EXIT_FAILURE;
-      }
-    catch(const HfstException & e)    {
+    catch (const ImplementationTypeNotAvailableException &e)
+    {
+        error(EXIT_FAILURE, 0,
+              "file %s is in %s format which is not available", inputfilename,
+              hfst::implementation_type_to_format(instream->get_type()));
+        return EXIT_FAILURE;
+    }
+    catch (const HfstException &e)
+    {
         error(EXIT_FAILURE, 0, "%s is not a valid transducer file",
               inputfilename);
         return EXIT_FAILURE;
     }
-    auto outstream = (outfile != stdout) ?
-        std::make_unique<HfstOutputStream>(outfilename, instream->get_type()) :
-        std::make_unique<HfstOutputStream>(instream->get_type());
-    
-    if ( is_input_stream_in_ol_format(*instream, "hfst-minimize"))
-      {
+    auto outstream
+        = (outfile != stdout)
+              ? std::make_unique<HfstOutputStream>(outfilename,
+                                                   instream->get_type())
+              : std::make_unique<HfstOutputStream>(instream->get_type());
+
+    if (is_input_stream_in_ol_format(*instream, "hfst-minimize"))
+    {
         return EXIT_FAILURE;
-      }
+    }
 
     retval = process_stream(*instream, *outstream);
 
     if (encode_weights)
-      {
+    {
         hfst::set_encode_weights(enc);
-      }
+    }
 
     free(inputfilename);
     free(outfilename);
     return retval;
 }
-
