@@ -14,12 +14,8 @@
 #  include <config.h>
 #endif
 
-#if USE_GLIB_UNICODE
-#  include <glib.h>
-#elif USE_ICU_UNICODE
-#  include <unicode/unistr.h>
-#  include <unicode/uchar.h>
-#endif
+#include <unicode/unistr.h>
+#include <unicode/uchar.h>
 
 #include <cstring>
 #include <cstdio>
@@ -66,7 +62,7 @@ LetterTrie::find_symbol(const char* c) const
 {
   if(strlen(c) == 1)
     return symbols[(unsigned char)(c[0])];
-  
+
   if(letters[(unsigned char)(c[0])] == NULL)
     return NO_SYMBOL_NUMBER;
   else
@@ -79,14 +75,14 @@ LetterTrie::extract_symbol(std::istream& is) const
   int c = is.get();
   if(c == EOF)
     return 0;
-    
+
   if(letters[c] == NULL)
   {
     if(symbols[c] == NO_SYMBOL_NUMBER)
       is.putback(c);
     return symbols[c];
   }
-  
+
   SymbolNumber s = letters[c]->extract_symbol(is);
   if(s == NO_SYMBOL_NUMBER)
   {
@@ -104,7 +100,7 @@ void
 Symbolizer::add_symbol(const std::string& symbol_str)
 {
   std::string p = symbol_str;
-  
+
   if(p.length() > 0)
   {
     unsigned char first = p.at(0);
@@ -148,7 +144,7 @@ Symbolizer::extract_symbol(std::istream& is) const
   if(ascii_symbols[c] == NO_SYMBOL_NUMBER ||
      ascii_symbols[c] == 0)
     return letters.extract_symbol(is);
-  
+
   return ascii_symbols[is.get()];
 }
 
@@ -168,16 +164,17 @@ ProcTransducerAlphabet::ProcTransducerAlphabet(std::istream& is,
       symbol_table[k] = "";
     symbolizer.add_symbol(symbol_table[k]);
   }
-  
+
   // assume the first symbol is epsilon which we don't want to print
   symbol_table[0] = "";
-  
+
   check_for_overlapping();
   setup_blank_symbol();
   calculate_caps();
   if(printDebuggingInformationFlag)
     print_table();
 
+
   escaped_symbols.insert(symbolizer.find_symbol("["));
   escaped_symbols.insert(symbolizer.find_symbol("]"));
   escaped_symbols.insert(symbolizer.find_symbol("{"));
@@ -189,6 +186,7 @@ ProcTransducerAlphabet::ProcTransducerAlphabet(std::istream& is,
   escaped_symbols.insert(symbolizer.find_symbol("@"));
   escaped_symbols.insert(symbolizer.find_symbol("<"));
   escaped_symbols.insert(symbolizer.find_symbol(">"));
+
 }
 
 void
@@ -203,7 +201,7 @@ ProcTransducerAlphabet::setup_blank_symbol()
       break;
     }
   }
-  
+
   if(blank_symbol == NO_SYMBOL_NUMBER)
   {
     blank_symbol = symbol_table.size();
@@ -218,27 +216,27 @@ void
 ProcTransducerAlphabet::check_for_overlapping() const
 {
   std::vector<std::string> overlapping;
-  
+
   for(size_t i=0;i<symbol_table.size();i++)
   {
     std::string str = symbol_table[i];
     if(str.length() > 1 && !is_punctuation(std::string(1, str[0]).c_str()))
     {
       std::istringstream s(str);
-      
+
       // divide the symbol into UTF8 characters
       std::vector<std::string> chars;
       while(true)
       {
         std::string ch = TokenIOStream::read_utf8_char(s);
-        if(ch == "")
+        if(ch.empty())
           break;
         else
           chars.push_back(ch);
       }
       if(chars.size() < 2)
         continue;
-      
+
       bool overlaps = true;
       for(size_t j=0;j<chars.size();j++)
       {
@@ -249,12 +247,12 @@ ProcTransducerAlphabet::check_for_overlapping() const
           break;
         }
       }
-      
+
       if(overlaps)
         overlapping.push_back(str);
     }
   }
-  
+
   if(!overlapping.empty())
   {
       if (! silentFlag)
@@ -291,12 +289,12 @@ ProcTransducerAlphabet::print_table() const
     }
     else
       std::cout << "no case";
-    
+
     if(fd_op != NULL)
       std::cout << " FD - feature: " << fd_op->Feature() << ", value: " << fd_op->Value();
     std::cout << std::endl;
   }
-  
+
   if(fd_table.num_features()>0)
     std::cout << "Alphabet contains " << fd_table.num_features() << " flag diacritic feature(s)" << std::endl;
 }
@@ -326,7 +324,7 @@ ProcTransducerAlphabet::calculate_caps()
       switched = caps_helper(symbol_table[i].c_str(), case_res);
     else
       case_res = 0;
-    
+
     if(case_res < 0)
     {
       symbol_properties_table[i].lower = i;
@@ -339,7 +337,7 @@ ProcTransducerAlphabet::calculate_caps()
     }
     else
       symbol_properties_table[i].lower=symbol_properties_table[i].upper=NO_SYMBOL_NUMBER;
-    
+
     if(to_lower(i) == to_upper(i) && symbol_properties_table[i].lower != NO_SYMBOL_NUMBER)
     {
       if(switched != "")
@@ -369,8 +367,8 @@ ProcTransducerAlphabet::calculate_caps()
           std::cout << "Symbol " << i << "'s alternate case is unknown" << std::endl;
       }
     }
-    
-    
+
+
     if(printDebuggingInformationFlag &&
        symbol_properties_table[i].lower != NO_SYMBOL_NUMBER && symbol_properties_table[i].upper != NO_SYMBOL_NUMBER &&
        symbol_to_string(symbol_properties_table[i].lower).length() != symbol_to_string(symbol_properties_table[i].upper).length())
@@ -383,7 +381,6 @@ ProcTransducerAlphabet::calculate_caps()
 std::string
 ProcTransducerAlphabet::caps_helper_single(const char* c, int& case_res)
 {
-#if USE_ICU_UNICODE
     icu::UnicodeString us(c);
     if (us.countChar32() == 1) {
         UChar32 uc = us.char32At(0);
@@ -404,160 +401,6 @@ ProcTransducerAlphabet::caps_helper_single(const char* c, int& case_res)
     }
     case_res = 0;
     return "";
-#elif USE_GLIB_UNICODE
-  glong readed = 0;
-  glong written = 0;
-  GError** gerrno;
-  gunichar* s = g_utf8_to_ucs4(c, -1, &readed, &written, gerrno);
-  gchar* cased = 0;
-  if (g_unichar_isupper(*s))
-    {
-      case_res = 1;
-      cased = g_utf8_strdown(c, -1);
-    }
-  else if (g_unichar_islower(*s))
-    {
-      case_res = -1;
-      cased = g_utf8_strup(c, -1);
-    }
-  else
-    {
-      case_res = 0;
-      cased = g_strdup("");
-    }
-  g_free(s);
-  string rv(cased);
-  return cased;
-#else
-  static const char* override_upper[21][2] = {{"Ə", "ə"},
-                                             {"Р", "р"},
-                                             {"А", "а"},
-                                             {"Ч", "ч"},
-                                             {"Ы", "ы"},
-                                             {"У", "у"},
-                                             {"Ю", "ю"},
-                                             {"Т", "т"},
-                                             {"С", "с"},
-                                             {"К", "к"},
-                                             {"Ш", "ш"},
-                                             {"Ө", "ө"},
-                                             {"Ф", "ф"},
-                                             {"Я", "я"},
-                                             {"Ц", "ц"},
-                                             {"М", "м"},
-                                             {"Е", "е"},
-                                             {"Х", "х"},
-                                             {"Ҡ", "ҡ"},
-                                             {"Һ", "һ"},
-                                             {"Э", "э"}};
-
-  static const char* override_lower[21][2] = {{"ə", "Ə"},
-                                             {"р", "Р"},
-                                             {"а", "А"},
-                                             {"ч", "Ч"},
-                                             {"ы", "Ы"},
-                                             {"у", "У"},
-                                             {"ю", "Ю"},
-                                             {"т", "Т"},
-                                             {"с", "С"},
-                                             {"к", "К"},
-                                             {"ш", "Ш"},
-                                             {"ө", "Ө"},
-                                             {"ф", "Ф"},
-                                             {"я", "Я"},
-                                             {"е", "Е"},
-                                             {"м", "М"},
-                                             {"ҡ", "Ҡ"},
-                                             {"ц", "Ц"},
-                                             {"х", "Х"},
-                                             {"һ", "Һ"},
-                                             {"э", "Э"}};
-
-  static const char* parallel_ranges[5][2][2] = {{{"A","Z"},{"a","z"}}, // Basic Latin
-                                                 {{"À","Þ"},{"à","þ"}}, // Latin-1 Supplement
-                                                 {{"Α","Ϋ"},{"α","ϋ"}}, // Greek and Coptic
-                                                 {{"А","Я"},{"а","я"}}, // Cyrillic
-                                                 {{"Ѐ","Џ"},{"ѐ","џ"}}};// Cyrillic
-  /**
-   * These letters in Latin Extended A have no corresponding
-   * capital/small, and thus shift the range by one:
-   U+0138 	ĸ	LATIN SMALL LETTER KRA (between ķ and Ĺ)
-   U+0149 	ŉ	LATIN SMALL LETTER N PRECEDED BY APOSTROPHE (between ň and Ŋ)
-   U+0178 	Ÿ	LATIN CAPITAL LETTER Y WITH DIAERESIS (U+0178) (between ŷ and Ź)
-   U+017F 	ſ	LATIN SMALL LETTER LONG S (U+017F) (between ž and the end of the block)
-   */
-  static const char* serial_ranges[13][3] = {{"Ā","ķ"}, // Latin Extended A
-                                             {"Ĺ","ň"}, // Latin Extended A
-                                             {"Ŋ","ŷ"}, // Latin Extended A
-                                             {"Ź","ž"}, // Latin Extended A
-                                             {"Ǎ","ǜ"}, // Latin Extended B
-                                             {"Ǟ","ǯ"}, // Latin Extended B
-                                             {"Ǵ","ȳ"}, // Latin Extended B
-                                             {"Ϙ","ϯ"}, // Greek and Coptic
-                                             {"Ѡ","ҿ"}, // Cyrillic
-                                             {"Ӂ","ӎ"}, // Cyrillic
-                                             {"Ӑ","ӿ"}, // Cyrillic
-                                             {"Ԁ","ԥ"}, // Cyrillic Supplement
-                                             {"Ḁ","ỿ"}}; //Latin Extended Additional
-
-  for(int i = 0; i < 21; i++)
-  {
-    if(strcmp(c,override_upper[i][0]) == 0)
-    {
-      case_res = 1;
-      return override_upper[i][1];
-    }
-  }
-
-  for(int i = 0; i < 21; i++)
-  {
-    if(strcmp(c,override_lower[i][0]) == 0)
-    {
-      case_res = -1;
-      return override_lower[i][1];
-    }
-  }
-
-  for(int i=0;i<5;i++) // check parallel ranges
-  {
-    if(strcmp(c,parallel_ranges[i][0][0]) >= 0 &&
-       strcmp(c,parallel_ranges[i][0][1]) <= 0) // in the uppercase section
-    {
-      case_res = 1;
-      int diff = utf8_str_to_int(parallel_ranges[i][1][0]) -
-                 utf8_str_to_int(parallel_ranges[i][0][0]);
-      return utf8_int_to_str(utf8_str_to_int(c)+diff);
-    }
-    else if(strcmp(c,parallel_ranges[i][1][0]) >= 0 &&
-            strcmp(c,parallel_ranges[i][1][1]) <= 0) // in the lowercase section
-    {
-      case_res = -1;
-      int diff = utf8_str_to_int(parallel_ranges[i][1][0]) -
-                 utf8_str_to_int(parallel_ranges[i][0][0]);
-      return utf8_int_to_str(utf8_str_to_int(c)-diff);
-    }
-  }
-  for(int i=0;i<12;i++) // check serial ranges
-  {
-    if(strcmp(c,serial_ranges[i][0]) >= 0 &&
-       strcmp(c,serial_ranges[i][1]) <= 0)
-    {
-      int c_int = utf8_str_to_int(c);
-      if((c_int-utf8_str_to_int(serial_ranges[i][0]))%2 == 0) // uppercase
-      {
-        case_res = 1;
-        return utf8_int_to_str(c_int+1);
-      }
-      else // lowercase
-      {
-        case_res = -1;
-        return utf8_int_to_str(c_int-1);
-      }
-    }
-  }
-  case_res = 0;
-  return "";
-#endif // HFST_UNICODE
 }
 
 std::string
@@ -567,14 +410,14 @@ ProcTransducerAlphabet::caps_helper(const char* in, int& case_res)
   std::string out;
   case_res = 0;
   int tmp = -2; // -2 indicates first time through the loop
-  
+
   std::vector<std::string> chars;
   while(true)
   {
     std::string c = TokenIOStream::read_utf8_char(str);
-    if(c == "")
+    if(c.empty())
       break;
-    
+
     std::string switched = caps_helper_single(c.c_str(), (tmp==-2?case_res:tmp));
     tmp=0;
     out.append((switched==""?c:switched));
@@ -620,13 +463,14 @@ ProcTransducerAlphabet::utf8_int_to_str(int c)
 }
 
 std::string
-ProcTransducerAlphabet::symbols_to_string(const SymbolNumberVector& symbols, CapitalizationState caps) const
+ProcTransducerAlphabet::symbols_to_string(const SymbolNumberVector& symbols, CapitalizationState caps, bool raw) const
 {
   std::string str="";
   bool first=true;
   for(SymbolNumberVector::const_iterator it=symbols.begin(); it!=symbols.end(); it++, first=false)
   {
-      if(!is_tag(*it) && escaped_symbols.find(*it) != escaped_symbols.end()) {
+      if(!is_tag(*it) && escaped_symbols.find(*it) != escaped_symbols.end() &&
+         !raw) {
           str += "\\";
       }
       if(caps==UpperCase || (caps==FirstUpperCase && first==true)) {
@@ -665,7 +509,7 @@ ProcTransducerAlphabet::is_punctuation(const char* c) const
       return true;
     }
   }
-  
+
   return (strstr(individual_chars, c) != NULL);
 }
 
